#!/bin/ksh
# IBM_PROLOG_BEGIN_TAG 
# This is an automatically generated prolog. 
#  
#  
#  
# Licensed Materials - Property of IBM 
#  
# (C) COPYRIGHT International Business Machines Corp. 2007,2010 
# All Rights Reserved 
#  
# US Government Users Restricted Rights - Use, duplication or 
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp. 
#  
# IBM_PROLOG_END_TAG 
# "@(#)66   1.16.1.2   src/sam/CHARM/cli/bin/eezauto.sh, charmcli, sam_rsa322, rsa3221138a 3/29/10 13:14:38"
#.-----------------------------------------------------------------.
#|                                                                 |
#| IBM Tivoli System Automation for Multiplatforms                 |
#| Policy for TSA end-to-end automation manager and engine         | 
#| Policy version: 1.0                                             |
#|                                                                 |
#| Generate EEZ resources                                          |
#| ======================                                          |
#|                                                                 |
#| This script creates all the EEZ groups and resources that are   |
#| required to automate an EEZ system.                             |
#'-----------------------------------------------------------------'
# Change Activity:                                                   #
#  070312 OAN 142229: Initial design & write.                        #
######################################################################
#
# all return codes
# $ok
ok=0
# $bad_call - incorrect options
bad_call=1
# $base-command-not-found - some base command was not found
base_command_not_found=2
# $no_top_file - policy top-level file not found
no_top_file=3
# $no_prop_file - properties file not found
no_prop_file=4
# $mkrpdomain_command_failed - mkrpdomain command failed
mkrpdomain_command_failed=5
# $sampolicy_command_failed - sampolicy command failed
sampolicy_command_failed=6
# $rmrpdomain_command_failed - rmrpdomain command failed
rmrpdomain_command_failed=7
# $startrpdomain_command_failed - startrpdomain command failed
startrpdomain_command_failed=8
# $preprpnode_command_failed - preprpnode command failed
preprpnode_command_failed=9
# $domain_does_not_exist - domain does not exist
domain_does_not_exist=10
# $domain_does_already_exist - domain does already exist
domain_does_already_exist=11
# $domain_is_offline - domain is offline - not able to remove it
domain_is_offline=12
# $no_write_to_out_file - not able to write to output file
no_write_to_out_file=13
# $eezautomate_failed - script failed generic problem
eezautomate_failed=14
# $eezautomate_usage - print usage statement
eezautomate_usage=15
# $no_relations_file - relations file not found
no_relations_file=16
# $no_fsrr_file - eezpolicyfsrr file not found
no_fsrr_file=17
# $no_alafsrr_file - eezpolicyalafsrr file not found
no_alafsrr_file=18
# $eezautomate_check_output - check policy output message needed
eezautomate_check_output=88
#

###############################################################################
function activatePolicy {
# returns 0 if ok
# return $sampolicy_command_failed
# return $no_top_file
# return $no_write_to_out_file
# return $eezautomate_failed
# return $eezautomate_check_output
#
# first check if IBM.AgFileSystem is defined - StorageRM is installed
  mkcmd "lsrsrc -t IBM.AgFileSystem"
  rc=$?
  if [[ $rc != 0 ]]
  then
    # IBM.AgFileSystem is not defined
    logger -puser.debug "eezautomate: IBM.AgFileSystem is not defined" 
    logger -puser.debug "eezautomate: Ensure the StorageRM is installed" 
    return $eezautomate_failed
  fi
# check whether the policy pool directory is already harvested
  numberOfRecords=$(lsrsrc -t -s "DeviceName='$eez_device_name'" IBM.AgFileSystem Name 2>/dev/null | wc -l )
  let numberOfRecords=numberOfRecords-1
  eez_fs_name=$(lsrsrc -t -s "DeviceName='$eez_device_name'" IBM.AgFileSystem Name | tr -d \" | awk 'NR > "'${numberOfRecords}'" { print $NF }')
  if [[ "${eez_fs_name}" = "" ]]; then
     USERR=0
  else
     USERR=1
  fi
# check whether the ala policy pool directory is already harvested
  numberOfRecords=$(lsrsrc -t -s "DeviceName='$ala_device_name'" IBM.AgFileSystem Name 2>/dev/null | wc -l )
  let numberOfRecords=numberOfRecords-1
  eez_fsala_name=$(lsrsrc -t -s "DeviceName='$ala_device_name'" IBM.AgFileSystem Name | tr -d \" | awk 'NR > "'${numberOfRecords}'" { print $NF }') 
  if [[ "${eez_fsala_name}" = "" ]]; then
     USEALARR=0
  else
     USEALARR=1
  fi
# check write to out-file
if [[ -w ${WORKING_DIR} ]]; then
  if [[ $VERBOSE != 0 ]]            
  then                         
     logger -puser.debug "eezautomate: writing to output directory is possible" 
     echo "writing to output directory is possible"
  fi                           
else
  # no able to write to out-file --> abending
  logger -puser.debug "eezautomate: Cannot write to ${WORKING_DIR}" 
  return $no_write_to_out_file
fi
# get configuration data
if [[ -r ${POLICY_TOP_FILE} ]]; then
  # now replace the placeholders with the correct values
  awk '{ gsub(/tsadomainname/, "'$tsa_domain_name'") ;
         gsub(/tsahostname1/, "'$tsa_hostname1'") ;
         gsub(/tsahostname2/, "'$tsa_hostname2'") ;
         gsub(/tsahostname3/, "'$tsa_hostname3'") ;
         gsub(/tsanetworktiebreakeripaddress/, "'$tsa_network_tiebreaker_IP_address'") ;
         gsub(/eeznameprefix/, "'$eez_name_prefix'") ;
         gsub(/eezipaddress/, "'$eez_ipv4_address'") ;
         gsub(/eezipmask/, "'$eez_ipv4_mask'") ;
         gsub(/eezipv6address/, "'$eez_ipv6_address'") ;
         gsub(/eezipprefix/, "'$eez_ip_prefix'") ;
         gsub(/waseezasname/, "'$was_eez_as_name'") ;
         gsub(/waseezasport/, "'$was_eez_as_port'") ;
         gsub(/wasprofiledir/, "'$was_profile_dir'") ;
         gsub(/eezdevicename/, "'$eez_device_name'") ;
         gsub(/eezmountpoint/, "'$eez_mount_point'") ;
         gsub(/eezvfs/, "'$eez_vfs'") ;
         gsub(/eezfsname/, "'$eez_fs_name'") ;
         gsub(/aladevicename/, "'$ala_device_name'") ;
         gsub(/alamountpoint/, "'$ala_mount_point'") ;
         gsub(/alavfs/, "'$ala_vfs'") ;
         gsub(/eezfsalaname/, "'$eez_fsala_name'") ;
         gsub(/eezeifreceiveport/, "'$eif_receive_from_port'") ;
         gsub(/eezinstalldir/, "'$eez_install_dir'") ;
         gsub(/eeznetworkinterface1/, "'$eez_network_interface1'") ;
         gsub(/eeznetworkinterface2/, "'$eez_network_interface2'") ;
         gsub(/eeznetworkinterface3/, "'$eez_network_interface3'") ;
         gsub(/db2instdir/, "'$db2_inst_dir'") ;
         gsub(/db2db2instance/, "'$db2_db2_instance'") ;
         gsub(/db2mountpoint/, "'$db2_mount_point'") ;
         print > "'$OUT_TOP_FILE'" }' ${POLICY_TOP_FILE} 2>/dev/null
  # put the xml to be activated together       
  prepareXML
  rc=$?
  if [[ $rc != 0 ]]
  then
     # preparing XML failed
     logger -puser.debug "eezautomate: prepareXML failed with rc: $rc" 
     return $rc
  fi
  # and adjust the relations and groups
  adjustRelationsAndGroups
  rc=$?
  if [[ $rc != 0 ]]
  then
     # adjusting relations xml failed
     logger -puser.debug "eezautomate: adjustRelationsAndGroups failed with rc: $rc" 
     return $rc
  fi
  # now the xml is ready --> call sampolicy
  # activate or deactivate or check
  if [[ $DEACTIVATE == 1 ]]            
  then             
    # it's deactivate
    if [[ $VERBOSE != 0 ]]            
    then                         
       logger -puser.debug "eezautomate: calling command: sampolicy -q -D -t ${OUT_TOP_FILE}" 
       echo "calling command: sampolicy -q -D -t ${OUT_TOP_FILE}"
    fi  
    # change dir to prop-file dir                         
    cd $WORKING_DIR
    sampolicy -q -D -t ${OUT_TOP_FILE}
    rc=$?
    if [[ $rc != 0 ]]
    then
       # sampolicy command failed
       logger -puser.debug "eezautomate: sampolicy command failed with rc: $rc" 
       return $sampolicy_command_failed
    else
       return 0
    fi
  else
    # it's activate or check
    # change dir to prop-file dir                         
    cd $WORKING_DIR
    if [[ $CHECK == 1 ]]            
    then
      if [[ $VERBOSE != 0 ]]            
      then                         
         logger -puser.debug "eezautomate: calling command: sampolicy -u -c -t ${OUT_TOP_FILE}" 
         echo "calling command: sampolicy -u -c -t ${OUT_TOP_FILE}"
      fi                           
      sampolicy -u -c -t ${OUT_TOP_FILE}
    else        
      if [[ $VERBOSE != 0 ]]            
      then                         
         logger -puser.debug "eezautomate: calling command: sampolicy -q -u -t ${OUT_TOP_FILE}" 
         echo "calling command: sampolicy -q -u -t ${OUT_TOP_FILE}"
      fi                           
      sampolicy -q -u -t ${OUT_TOP_FILE}
    fi     
    rc=$?
    if [[ $rc != 0 ]]
    then
       # sampolicy command failed
       logger -puser.debug "eezautomate: sampolicy command failed with rc: $rc" 
       return $sampolicy_command_failed
    else
       return 0
    fi
  fi            
else
  # no top level xml file found --> abending
  logger -puser.debug "eezautomate: Cannot read ${POLICY_TOP_FILE}" 
  return $no_top_file
fi
}

###############################################################################
function checkDomainState {
# return state
#  3 lsrpdomain command is unknown
#  0 domain does not exist
#  1 Online
#  2 Offline

  response=$(lsrpdomain)
  if [[ $? == 0 ]]; then
    response=$(lsrpdomain | tr -d \" | grep -E "^$tsa_domain_name " | cut -d' ' -f1 2>/dev/null)
       
    if [[ $VERBOSE != 0 ]]            
    then                         
       logger -puser.debug "eezautomate: lsrpdomain response: $response" 
       echo "lsrpdomain response:" $response
    fi                           
    if [ "X${response}" != "X$tsa_domain_name" ]
    then
        # domain does not exist yet
        if [[ $VERBOSE != 0 ]]            
        then                         
           logger -puser.debug "eezautomate: domain ${tsa_domain_name} does NOT exist" 
           echo "domain ${tsa_domain_name} does not exist"
           echo "returning 0"
        fi                           
        return 0
    else
        if [[ $VERBOSE != 0 ]]            
        then                         
           logger -puser.debug "eezautomate: domain ${tsa_domain_name} does exist" 
           echo "domain ${tsa_domain_name} does exist"
        fi                           
    fi
    response=$(lsrpdomain $tsa_domain_name | tr -d \" |  grep -E "^$tsa_domain_name " | grep "Online" 2>/dev/null)
    if [[ $? == 0 ]]
    then
       return 1
    else
       return 2
    fi
  else
    # lsrpdomain command not found
    if [[ $VERBOSE != 0 ]]            
    then                         
       logger -puser.debug "eezautomate: lsrpdomain command failed" 
       echo "lsrpdomain command failed"
    fi                           
    return 3
  fi
}

###############################################################################
function createDomain {
# returns
# 0 ok
# 1 domain is already online
# 2 lsrpdomain-command not found
# 3 domain already exists, but is offline
# 5 mkrpdomain command failed
# 9 preprpnode command failed

  # check domain
  checkDomainState
 
 case $? in 
    0) 
      if [[ $VERBOSE != 0 ]]            
      then                         
         logger -puser.debug "eezautomate: Domain does not exist." 
         echo "Domain does not exist."
      fi;;
    1) 
      if [[ $VERBOSE != 0 ]]            
      then                         
         logger -puser.debug "eezautomate: Domain is online." 
         echo "Domain is online."
      fi                           
      return 1;;
    2) 
      if [[ $VERBOSE != 0 ]]            
      then                         
         logger -puser.debug "eezautomate: Domain is offline." 
         echo "Domain is offline."
      fi                           
      return 3;;
    3) 
      logger -puser.debug "eezautomate: lsrpdomain command not found." 
      return $base_command_not_found;;
 esac
  
  # Prepare the nodes - on all remote nodes the preprpnode command has already been executed by the Dialog
  # just do it locally here
  mkcmd "${preprpCommand}"
  if [[ $? != 0 ]]
  then
     # preprpnode command failed
     logger -puser.debug "eezautomate: preprpnode command failed" 
     return $preprpnode_command_failed
  fi
  
  # create the domain
  #mkcmd "mkrpdomain ${tsa_domain_name} ${tsa_hostname1} ${tsa_hostname2} ${tsa_hostname3}"
  mkcmd "${makeCommand}"
  if [[ $? != 0 ]]
  then
     # mkrpdomain command failed
     logger -puser.debug "eezautomate: mkrpdomain command failed" 
     return $mkrpdomain_command_failed
  else
     return 0
  fi
}

###############################################################################
function checkPolicy {
# returns 0 if ok
# return $sampolicy_command_failed
#
  # now call sampolicy
  # set check flag first - then call activatePolicy
  CHECK=1
  activatePolicy
  return $?
}

###############################################################################
function deactivatePolicy {
# returns 0 if ok
# return $sampolicy_command_failed
#
  # now call sampolicy
  # set deactivate flag first - then call activatePolicy
  DEACTIVATE=1
  activatePolicy
  return $?
}

###############################################################################
function isIPv6 {
# returns 0 if IPv4
# returns 1 if IPv6
#
 rc=0
 if [[ $VERBOSE != 0 ]]            
 then                         
    logger -puser.debug "eezautomate: eez_ip_address is $eez_ip_address" 
    echo "eez_ip_address is $eez_ip_address"
 fi
 if [[ "$eez_ip_address" = *:* ]]
 then
   if [[ $VERBOSE != 0 ]]            
   then                         
      logger -puser.debug "eezautomate: found colon -> IPv6" 
      echo "found colon -> IPv6"
   fi
   rc=1
   IPV6=1
 fi
 return $rc
}

###############################################################################
function isIPv4AndIPv6 {
# returns 2 if IPv4 and IPv6 are used both
# returns 1 if IPv6 is used
# returns 0 if IPv4 is used
#
 if [[ $VERBOSE != 0 ]]            
 then                         
   logger -puser.debug "eezautomate: eez_ip_address is $eez_ip_address" 
   echo "eez_ip_address is $eez_ip_address"
 fi
 if [[ "$eez_ip_address" = *,* ]]
 then
   if [[ $VERBOSE != 0 ]]            
   then                         
     logger -puser.debug "eezautomate: found comma -> IPv4 and IPv6 are used both" 
     echo "found comma -> IPv4 and IPv6 are used both"
   fi
   IPV6=2
   eez_ipv4_address=${eez_ip_address%%,*}
   eez_ipv6_address=${eez_ip_address#*,}
   eez_ipv4_mask=${eez_ip_mask%%,*}
   eez_ip_prefix=${eez_ip_mask#*,}
 else
   if [[ "$eez_ip_address" = *:* ]]
   then
     if [[ $VERBOSE != 0 ]]            
     then                         
       logger -puser.debug "eezautomate: found colon -> IPv6 is used" 
       echo "found colon -> IPv6 is used"
     fi
     IPV6=1
     eez_ipv6_address=${eez_ip_address}
     eez_ip_prefix=${eez_ip_mask}
   else
     if [[ $VERBOSE != 0 ]]            
     then                         
       logger -puser.debug "eezautomate: no colon -> IPv4 is used" 
       echo "no colon -> IPv4 is used"
     fi
     IPV6=0
     eez_ipv4_address=${eez_ip_address}
     eez_ipv4_mask=${eez_ip_mask}
   fi
 fi
 if [[ $VERBOSE != 0 ]]            
 then                         
   logger -puser.debug "eezautomate: eez_ipv4_address is $eez_ipv4_address"
   logger -puser.debug "eezautomate: eez_ipv6_address is $eez_ipv6_address"
   logger -puser.debug "eezautomate: eez_ipv4_mask is $eez_ipv4_mask"
   logger -puser.debug "eezautomate: eez_ip_prefix is $eez_ip_prefix"
   echo "eez_ipv4_address is $eez_ipv4_address"
   echo "eez_ipv6_address is $eez_ipv6_address"
   echo "eez_ipv4_mask is $eez_ipv4_mask"
   echo "eez_ip_prefix is $eez_ip_prefix"
 fi
 return $IPV6
}

###############################################################################
function adjustRelationsAndGroups {
# returns 0 if ok
# return $no_relations_file
#
# remove the relations and group members not needed within eezrelations.xml
  
if [[ -r ${RELATIONS_FILE} ]]
then
  rm -f $RELATIONS_FILE_OUT 2>/dev/null
  rm -f $RELATIONS_FILE_OUT2 2>/dev/null
  cp $RELATIONS_FILE $RELATIONS_FILE_OUT
  # now remove the relations specific for each policy
  # local DB2 used or not
  if [ "${db2_automate}" != "yes" ]
  then
    if [[ $VERBOSE != 0 ]]            
    then                         
       logger -puser.debug "eezautomate: removing DB2 relations" 
       echo "removing DB2 relations"
    fi
    sed -e "/!!dDm!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
    sed -e "/!!wDd!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
    sed -e "/!!rgsrvdb2!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
    sed -e "/!!rgsrvdb2hwa!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
  fi
  # HWA used or not
  if [ "${hwa_automate}" != "yes" ]
  then
    if [[ $VERBOSE != 0 ]]            
    then                         
       logger -puser.debug "eezautomate: removing HWA relations" 
       echo "removing HWA relations"
    fi
    sed -e "/!!hwaSe!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
    sed -e "/!!gDw!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
    sed -e "/!!rgsrvhwa!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
    sed -e "/!!rgsrvdb2hwa!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
  else
    # remove also some stuff if both are yes
    if [ "${db2_automate}" == "yes" ]
    then
      sed -e "/!!rgsrvdb2!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
      cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
      sed -e "/!!rgsrvhwa!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
      cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
    fi
  fi
  # agentless adapter used or not
  if [ "${ala_automate}" != "yes" ]
  then
    if [[ $VERBOSE != 0 ]]            
    then                         
       logger -puser.debug "eezautomate: removing ALA relations" 
       echo "removing ALA relations"
    fi  
    sed -e "/!!mSOala!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
    sed -e "/!!alaSm!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
    sed -e "/!!mrrSOala!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
    sed -e "/!!alaSmrr!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
    sed -e "/!!alaSe!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
    sed -e "/!!alaAAe!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
    sed -e "/!!eAAala!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
    sed -e "/!!rgala!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
    sed -e "/!!rgmbrrrala!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
    sed -e "/!!rgmbrmgala!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
  else
    # agentless adapter is used
    # handle the file systems - user-defined or harvested (ResourceReferences)                 
    if [ $USEALARR != 1 ]
    then
      if [[ $VERBOSE != 0 ]]            
      then                         
         logger -puser.debug "eezautomate: removing ala harvested stuff" 
         echo "removing ala harvested stuff"
      fi                           
      sed -e "/!!mrrSOala!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
      cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
      sed -e "/!!alaSmrr!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
      cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
      sed -e "/!!rgmbrrrala!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
      cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
    else     
      if [[ $VERBOSE != 0 ]]            
      then                         
         logger -puser.debug "eezautomate: removing ala user-defined file system stuff" 
         echo "removing ala user-defined file system stuff"
      fi                           
      sed -e "/!!mSOala!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
      cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
      sed -e "/!!alaSm!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
      cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
      sed -e "/!!rgmbrmgala!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
      cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
    fi
  fi
  # handle the file systems - user-defined or harvested (ResourceReferences)                 
  if [ $USERR != 1 ]
  then
    if [[ $VERBOSE != 0 ]]            
    then                         
       logger -puser.debug "eezautomate: removing harvested stuff" 
       echo "removing harvested stuff"
    fi                           
    sed -e "/!!mrrSOe!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
    sed -e "/!!eSmrr!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
    sed -e "/!!rgmbrrr!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
  else     
    if [[ $VERBOSE != 0 ]]            
    then                         
       logger -puser.debug "eezautomate: removing user-defined file system stuff" 
       echo "removing user-defined file system stuff"
    fi                           
    sed -e "/!!mSOe!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
    sed -e "/!!eSm!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
    sed -e "/!!rgmbrmg!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
    cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
  fi
  # handle IPv4 or IPv6
  case ${IPV6} in 
      0) 
        if [[ $VERBOSE != 0 ]]            
        then                         
           logger -puser.debug "eezautomate: removing v6 stuff" 
           echo "removing v6 stuff"
        fi
        sed -e "/!!mgv6!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
        cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
        sed -e "/!!ipv6Dn!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
        cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
        ;;
      1) 
        if [[ $VERBOSE != 0 ]]            
        then                         
           logger -puser.debug "eezautomate: removing v4 stuff" 
           echo "removing v4 stuff"
        fi
        sed -e "/!!mgv4!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
        cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
        sed -e "/!!ipDn!!/d" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
        cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT
        ;;
      2) 
        ;;
  esac
  # finally remove all the markers in order to make the xml valid
  sed -e "s/!![a-z,A-Z,0-9]*!!//" $RELATIONS_FILE_OUT > $RELATIONS_FILE_OUT2
  cp $RELATIONS_FILE_OUT2 $RELATIONS_FILE_OUT

else
  # no relations xml file found --> abending
  logger -puser.debug "eezautomate: Cannot read ${RELATIONS_FILE}" 
  return $no_relations_file
fi
return $ok
}

###############################################################################
function prepareXML {
# returns 0 if ok
# returns $no_fsrr_file, if fsrr file not found
# returns $no_alafsrr_file, if alafsrr file not found
#
# puts the xml together - includes are removed or adjusted
# first adjust the hostnames and network-interfaces according to the number of nodes
if [[ -r ${FSRR_FILE} ]]
then
  rm -f $FSRR_FILE_OUT 2>/dev/null
  rm -f $FSRR_FILE_OUT2 2>/dev/null
  cp $FSRR_FILE $FSRR_FILE_OUT
else
  # no fsrr xml file found --> abending
  logger -puser.debug "eezautomate: Cannot read ${FSRR_FILE}" 
  return $no_fsrr_file
fi
if [[ -r ${ALAFSRR_FILE} ]]
then
  rm -f $ALAFSRR_FILE_OUT 2>/dev/null
  rm -f $ALAFSRR_FILE_OUT2 2>/dev/null
  cp $ALAFSRR_FILE $ALAFSRR_FILE_OUT
else
  # no alafsrr xml file found --> abending
  logger -puser.debug "eezautomate: Cannot read ${ALAFSRR_FILE}" 
  return $no_alafsrr_file
fi
if [[ $VERBOSE != 0 ]]            
then                         
   logger -puser.debug "eezautomate: using $NODES nodes" 
   echo "using $NODES nodes"
fi          
if [ $NODES == 1 ]
then
  sed -e "/name=\"tsa_hostname2\" value=/d" ${OUT_TOP_FILE} > $OUT_TOP_FILE2 
  cp $OUT_TOP_FILE2 $OUT_TOP_FILE
  sed -e "/name=\"tsa_hostname3\" value=/d" ${OUT_TOP_FILE} > $OUT_TOP_FILE2 
  cp $OUT_TOP_FILE2 $OUT_TOP_FILE 
  sed -e "/nodename>%%tsa_hostname2%%/d" ${OUT_TOP_FILE} > $OUT_TOP_FILE2 
  cp $OUT_TOP_FILE2 $OUT_TOP_FILE
  sed -e "/nodename>%%tsa_hostname3%%/d" ${OUT_TOP_FILE} > $OUT_TOP_FILE2 
  cp $OUT_TOP_FILE2 $OUT_TOP_FILE 
  sed -e "s/name=\"eez_network_interface2\" value=\"[a-z,A-Z,0-9,_,.,-]*\"/name=\"eez_network_interface2\" value=\"-\"/" ${OUT_TOP_FILE} > $OUT_TOP_FILE2 
  cp $OUT_TOP_FILE2 $OUT_TOP_FILE
  sed -e "s/name=\"eez_network_interface3\" value=\"[a-z,A-Z,0-9,_,.,-]*\"/name=\"eez_network_interface3\" value=\"-\"/" ${OUT_TOP_FILE} > $OUT_TOP_FILE2 
  cp $OUT_TOP_FILE2 $OUT_TOP_FILE
else
  # more than one node --> remove nodename from ResourceReferences
  sed -e "s/%%tsa_hostname1%%//" ${FSRR_FILE_OUT} > $FSRR_FILE_OUT2 
  cp $FSRR_FILE_OUT2 $FSRR_FILE_OUT
  sed -e "s/%%tsa_hostname1%%//" ${ALAFSRR_FILE_OUT} > $ALAFSRR_FILE_OUT2 
  cp $ALAFSRR_FILE_OUT2 $ALAFSRR_FILE_OUT
  if [ $NODES == 2 ]
  then
    sed -e "/name=\"tsa_hostname3\" value=/d" ${OUT_TOP_FILE} > $OUT_TOP_FILE2 
    cp $OUT_TOP_FILE2 $OUT_TOP_FILE 
    sed -e "/nodename>%%tsa_hostname3%%/d" ${OUT_TOP_FILE} > $OUT_TOP_FILE2 
    cp $OUT_TOP_FILE2 $OUT_TOP_FILE
  sed -e "s/name=\"eez_network_interface3\" value=\"[a-z,A-Z,0-9,_,.,-]*\"/name=\"eez_network_interface3\" value=\"-\"/" ${OUT_TOP_FILE} > $OUT_TOP_FILE2 
  cp $OUT_TOP_FILE2 $OUT_TOP_FILE
  fi
fi
# now handle the includes
# handle the file systems - user-defined or harvested (ResourceReferences)                 
if [ $USERR != 1 ]
then
  if [[ $VERBOSE != 0 ]]            
  then                         
     logger -puser.debug "eezautomate: using user-defined file system" 
     echo "using user-defined file system"
  fi                           
     awk '{ gsub(/eezpolicyfsrr-tmp.xml/, "eezpolicyfs.xml") ;
            print > "'$OUT_TOP_FILE2'" }' ${OUT_TOP_FILE} 2>/dev/null
     cp $OUT_TOP_FILE2 $OUT_TOP_FILE
else     
  if [[ $VERBOSE != 0 ]]            
  then                         
     logger -puser.debug "eezautomate: using harvested file system" 
     echo "using harvested file system"
  fi                           
fi
# handle DB2
if [ "${db2_automate}" == "yes" ]
then
  if [[ $VERBOSE != 0 ]]            
  then                         
     logger -puser.debug "eezautomate: using local DB2" 
     echo "using local DB2"
  fi                           
  awk '{ gsub(/eezpolicydb2.xml/, "'$INC_DB2'") ;
         print > "'$OUT_TOP_FILE2'" }' ${OUT_TOP_FILE} 2>/dev/null
  cp $OUT_TOP_FILE2 $OUT_TOP_FILE
else
  if [[ $VERBOSE != 0 ]]            
  then                         
     logger -puser.debug "eezautomate: NOT using local DB2" 
     echo "NOT using local DB2"
  fi
  awk '{ gsub(/eezpolicydb2.xml/, " ") ;
         print > "'$OUT_TOP_FILE2'" }' ${OUT_TOP_FILE} 2>/dev/null
  cp $OUT_TOP_FILE2 $OUT_TOP_FILE
fi    
# handle hardware-adapter / DDR stuff                         
if [ "${hwa_automate}" == "yes" ]
then
  if [[ $VERBOSE != 0 ]]            
  then                         
      logger -puser.debug "eezautomate: adding HWA policy" 
      echo "adding HWA policy"
  fi                           
  awk '{ gsub(/eezpolicyhwa.xml/, "'$INC_HWA'") ;
         print > "'$OUT_TOP_FILE2'" }' ${OUT_TOP_FILE} 2>/dev/null
  cp $OUT_TOP_FILE2 $OUT_TOP_FILE
else
  if [[ $VERBOSE != 0 ]]            
  then                         
     logger -puser.debug "eezautomate: NOT adding HWA" 
     echo "NOT adding HWA"
  fi                           
  awk '{ gsub(/eezpolicyhwa.xml/, " ") ;
         print > "'$OUT_TOP_FILE2'" }' ${OUT_TOP_FILE} 2>/dev/null
  cp $OUT_TOP_FILE2 $OUT_TOP_FILE
fi
# handle IPv4 resp. IPv6 stuff
case ${IPV6} in 
    0) 
      if [[ $VERBOSE != 0 ]]            
      then                         
         logger -puser.debug "eezautomate: using IPv4." 
         echo "using IPv4."
      fi
      ;;
    1) 
      if [[ $VERBOSE != 0 ]]            
      then                         
         logger -puser.debug "eezautomate: using IPv6." 
         echo "using IPv6."
      fi                           
      awk '{ gsub(/eezpolicyipv4.xml/, "eezpolicyipv6.xml") ;
             print > "'$OUT_TOP_FILE2'" }' ${OUT_TOP_FILE} 2>/dev/null
      cp $OUT_TOP_FILE2 $OUT_TOP_FILE
      ;;
    2) 
      if [[ $VERBOSE != 0 ]]            
      then                         
         logger -puser.debug "eezautomate: using IPv4 and IPv6." 
         echo "using IPv4 and IPv6."
      fi                           
      awk '{ gsub(/eezpolicyipv4.xml/, "eezpolicyipv46.xml") ;
             print > "'$OUT_TOP_FILE2'" }' ${OUT_TOP_FILE} 2>/dev/null
      cp $OUT_TOP_FILE2 $OUT_TOP_FILE
      ;;
esac
# handle tie-breaker-xml
if [ "${tsa_network_tiebreaker_IP_address}" != "" ]     
then
  # network tie-breaker is used
  if [[ $VERBOSE != 0 ]]            
  then                         
     logger -puser.debug "eezautomate: using network tie-breaker" 
     echo "using network tie-breaker"
  fi                           
  awk '{ gsub(/eeztie-breaker.xml/, "'$INC_NETTB'") ;
         print > "'$OUT_TOP_FILE2'" }' ${OUT_TOP_FILE} 2>/dev/null
  cp $OUT_TOP_FILE2 $OUT_TOP_FILE
else
  if [[ $VERBOSE != 0 ]]            
  then                         
     logger -puser.debug "eezautomate: NOT using network tie-breaker" 
     echo "NOT using network tie-breaker"
  fi                           
  awk '{ gsub(/eeztie-breaker.xml/, " ") ;
         print > "'$OUT_TOP_FILE2'" }' ${OUT_TOP_FILE} 2>/dev/null
  cp $OUT_TOP_FILE2 $OUT_TOP_FILE
fi
# handle ala xml
if [ "${ala_automate}" == "yes" ]
then
  # agentless adapter is used
  if [[ $VERBOSE != 0 ]]            
  then                         
     logger -puser.debug "eezautomate: using agentless adapter" 
     echo "using agentless adapter"
  fi                           
  awk '{ gsub(/eezpolicyala.xml/, "'$INC_ALA'") ;
         print > "'$OUT_TOP_FILE2'" }' ${OUT_TOP_FILE} 2>/dev/null
  cp $OUT_TOP_FILE2 $OUT_TOP_FILE
  # handle the file systems - user-defined or harvested (ResourceReferences)                 
  if [ $USEALARR != 1 ]
  then
    if [[ $VERBOSE != 0 ]]            
    then                         
       logger -puser.debug "eezautomate: using ala user-defined file system" 
       echo "using ala user-defined file system"
    fi                           
    awk '{ gsub(/eezpolicyalafsrr.xml/, "'$INC_ALAFS'") ;
           print > "'$OUT_TOP_FILE2'" }' ${OUT_TOP_FILE} 2>/dev/null
    cp $OUT_TOP_FILE2 $OUT_TOP_FILE
  else     
    if [[ $VERBOSE != 0 ]]            
    then                         
       logger -puser.debug "eezautomate: using ala harvested file system" 
       echo "using ala harvested file system"
    fi                           
    awk '{ gsub(/eezpolicyalafsrr.xml/, "'$INC_ALAFSRR'") ;
           print > "'$OUT_TOP_FILE2'" }' ${OUT_TOP_FILE} 2>/dev/null
    cp $OUT_TOP_FILE2 $OUT_TOP_FILE
  fi
else
  if [[ $VERBOSE != 0 ]]            
  then                         
     logger -puser.debug "eezautomate: NOT using agentless adapter" 
     echo "NOT using agentless adapter"
  fi                           
  awk '{ gsub(/eezpolicyala.xml/, " ") ;
         print > "'$OUT_TOP_FILE2'" }' ${OUT_TOP_FILE} 2>/dev/null
  cp $OUT_TOP_FILE2 $OUT_TOP_FILE
  awk '{ gsub(/eezpolicyalafsrr.xml/, " ") ;
         print > "'$OUT_TOP_FILE2'" }' ${OUT_TOP_FILE} 2>/dev/null
  cp $OUT_TOP_FILE2 $OUT_TOP_FILE
fi
# top-level policy xml is ready now
return $ok
}

###############################################################################
function deleteDomain {
# returns
# 0 ok
# 2 lsrpdomain-command not found
# 7 rmrpdomain command failed
# 10 domain does not exist
# 12 domain is offline

  # check domain
  checkDomainState
 
 case $? in 
    0) 
      if [[ $VERBOSE != 0 ]]            
      then                         
         logger -puser.debug "eezautomate: Domain does not exist." 
         echo "Domain does not exist."
      fi                           
      return $domain_does_not_exist;;
    1) 
      if [[ $VERBOSE != 0 ]]            
      then                         
         logger -puser.debug "eezautomate: Domain is online." 
         echo "Domain is online."
      fi;;
    2) 
      if [[ $VERBOSE != 0 ]]            
      then                         
         logger -puser.debug "eezautomate: Domain is offline." 
         echo "Domain is offline."
      fi   
      # do NOT start domain - return error message instead                        
      logger -puser.debug "eezautomate: Domain is offline - not able to remove it." 
      return $domain_is_offline;;
    3) 
      logger -puser.debug "eezautomate: lsrpdomain command not found." 
      return $base_command_not_found;;
 esac
 
  # remove the cluster informations from the systems
  mkcmd "rmrpdomain ${tsa_domain_name}"
  rc=$?
  if [[ $rc != 0 ]]
  then
     # rmrpdomain command failed
     logger -puser.debug "eezautomate: rmrpdomain command failed" 
     return $rmrpdomain_command_failed
  else
     return 0
  fi
}

###############################################################################
function mkcmd {
# return 0 or error code from called command
   cmd=$1
   
   if [[ $VERBOSE != 0 ]]            
   then                         
      echo ${cmd}
   fi                           
   response=`eval ${cmd} 2>&1`
   rc=$?

   if [[ $VERBOSE != 0 ]]            
   then                         
      logger -puser.debug "eezautomate: response: ${response}" 
      echo -e "${response}"
   fi                           
   
   if [[ $rc -ne 0 ]]; then     
     logger -puser.debug "eezautomate: response: ${response}" 
     echo -e "${response}"
     logger -puser.debug "eezautomate: error return code: ${rc}" 
     return $rc
   fi
   sleep 1
}

###############################################################################
function startDomain {
# return 0
# return $startrpdomain_command_failed

  # Start the domain
  mkcmd "startrpdomain ${tsa_domain_name}"
  rc=$?
  if [[ $rc != 0 ]]
  then
     # startrpdomain command failed
     logger -puser.debug "eezautomate: startrpdomain command failed" 
     return $startrpdomain_command_failed
  else
     return 0
  fi
}

###############################################################################
function startScript
{
  if [[ $VERBOSE != 0 ]]            
  then                         
     logger -puser.debug "eezautomate: ${SCRIPT_NAME} ${SCRIPT_OPTION} started" 
     echo "${SCRIPT_NAME} ${SCRIPT_OPTION} started on ..."
     date
  fi                           
}

###############################################################################
function stopScript
{
  if [[ $VERBOSE != 0 ]]            
  then                         
     logger -puser.debug "eezautomate: ${SCRIPT_NAME} ${SCRIPT_OPTION} finished" 
     echo "${SCRIPT_NAME} ${SCRIPT_OPTION} finished."
  fi                           
  # remove out file ???
}

###############################################################################
function printHelp
{
  echo "Usage: ${SCRIPT_NAME} [-h] [-V] [-createDomain|-deleteDomain|-activatePolicy
                              |-checkPolicy|-deactivatePolicy|-createAll|-deleteAll] propertiesFilePath"
  echo "  -createDomain,      Creates the TSA domain."
  echo "  -deleteDomain,      Deletes the TSA domain."
  echo "  -activatePolicy,    Activates the e2e policy."
  echo "  -deactivatePolicy,  Deactivates the active policy."
  echo "  -checkPolicy,       Creates and checks the e2e policy."
  echo "  -createAll,         Creates the TSA domain and activates the e2e policy."
  echo "  -deleteAll,         Deactivates the active policy and deletes the TSA domain."
  echo "  -h,                 Print this help."
  echo "  -V,                 Verbose mode."
  echo "  propertiesFilePath  complete path to the properties file."
}

###############################################################################
# main
###############################################################################
export CT_MANAGEMENT_SCOPE=2

# process options
SCRIPT_NAME=$0
SCRIPT_OPTION=$1
SCRIPT_CONFIG_FILE=$2
VERBOSE=0
NODES=2
USERR=1
USEALARR=1
DEACTIVATE=0
CHECK=0
IPV6=0
POLICY_TOP_FILE=/usr/sbin/rsct/xmlpolicies/eezpolicy-top.xml
RELATIONS_FILE=/usr/sbin/rsct/xmlpolicies/eezrelations.xml
RELATIONS_FILE_OUT=/usr/sbin/rsct/xmlpolicies/eezrelations-tmp.xml
RELATIONS_FILE_OUT2=/usr/sbin/rsct/xmlpolicies/eezrelations-tmp.tmp.xml
FSRR_FILE=/usr/sbin/rsct/xmlpolicies/eezpolicyfsrr.xml
FSRR_FILE_OUT=/usr/sbin/rsct/xmlpolicies/eezpolicyfsrr-tmp.xml
FSRR_FILE_OUT2=/usr/sbin/rsct/xmlpolicies/eezpolicyfsrr-tmp.tmp.xml
ALAFSRR_FILE=/usr/sbin/rsct/xmlpolicies/eezpolicyalafsrr.xml
ALAFSRR_FILE_OUT=/usr/sbin/rsct/xmlpolicies/eezpolicyalafsrr-tmp.xml
ALAFSRR_FILE_OUT2=/usr/sbin/rsct/xmlpolicies/eezpolicyalafsrr-tmp.tmp.xml
INC_EEZ2="<include>/usr/sbin/rsct/xmlpolicies/eezpolicy.xml</include>"
INC_DB2="<include>/usr/sbin/rsct/xmlpolicies/eezpolicydb2.xml</include>"
INC_HWA="<include>/usr/sbin/rsct/xmlpolicies/eezpolicyhwa.xml</include>"
INC_NETTB="<include>/usr/sbin/rsct/xmlpolicies/eeztie-breaker.xml</include>"
INC_IPv4="<include>/usr/sbin/rsct/xmlpolicies/eezpolicyipv4.xml</include>"
INC_IPv6="<include>/usr/sbin/rsct/xmlpolicies/eezpolicyipv6.xml</include>"
INC_IPv46="<include>/usr/sbin/rsct/xmlpolicies/eezpolicyipv46.xml</include>"
INC_ALA="<include>/usr/sbin/rsct/xmlpolicies/eezpolicyala.xml</include>"
INC_ALAFS="<include>/usr/sbin/rsct/xmlpolicies/eezpolicyalafs.xml</include>"
INC_ALAFSRR="<include>/usr/sbin/rsct/xmlpolicies/eezpolicyalafsrr-tmp.xml</include>"
RC=0

if [[ "X${SCRIPT_OPTION}" = "X-h" ]]; then 
  exit $eezautomate_usage
fi

# shift params if -V was specified
if [[ "X${SCRIPT_OPTION}" = "X-V" ]]; then 
  VERBOSE=1
  SCRIPT_OPTION=$2
  SCRIPT_CONFIG_FILE=$3
fi

if [[ $VERBOSE != 0 ]]            
then                         
   logger -puser.debug "eezautomate: reading properties file ${SCRIPT_CONFIG_FILE}" 
   echo "reading properties file ${SCRIPT_CONFIG_FILE}"
fi                           
# get configuration data
if [[ -r ${SCRIPT_CONFIG_FILE} ]]; then
  . "${SCRIPT_CONFIG_FILE}"
else
  logger -puser.debug "eezautomate: Cannot read ${SCRIPT_CONFIG_FILE}" 
  logger -puser.debug "eezautomate: ${SCRIPT_NAME} ${SCRIPT_OPTION} finished." 
  exit $no_prop_file
fi

# init some variables
# use directory of input properties-file for output as well
WORKING_DIR=${SCRIPT_CONFIG_FILE%eezautomate.properties}
OUT_TOP_FILE=${SCRIPT_CONFIG_FILE%.properties}
OUT_TOP_FILE2=${OUT_TOP_FILE}
OUT_TOP_FILE=${OUT_TOP_FILE}-policy-top.tmp
OUT_TOP_FILE2=${OUT_TOP_FILE2}-policy-top.tmp.tmp

# eez_network_interfaces=eth0:sapb01,eth0:sapb02
# hostnames for the policy and network interfaces
eez_network_interface1=${eez_network_interfaces%%:*}
rest=${eez_network_interfaces#*:}
tsa_hostname1=${rest%%,*}
rest=${rest#*,}
eez_network_interface2=${rest%%:*}
rest=${rest#*:}
tsa_hostname2=${rest%%,*}
rest=${rest#*,}
eez_network_interface3=${rest%%:*}
rest=${rest#*:}
tsa_hostname3=${rest%%,*}
rest=${rest#*,}


# do we have 3 nodes ?
if [[ "${tsa_hostname2}" != "${tsa_hostname3}" ]]; then
   NODES=3
fi
# do we have 1 or 2 nodes ?
if [[ "${tsa_hostname1}" = "${tsa_hostname2}" ]]; then
   NODES=1
fi
# tsa_hostnames=sapb01,sapb02
# init nodenames for the cluster setup
nodename[1]=${tsa_hostnames%%,*}
rest=${tsa_hostnames#*,}
lastName=${nodename[1]}
# loop until all nodes are added
suffix=1
while true
do
  if [[ "${rest}" = "${lastName}" ]]
  then
    break
  fi
  let suffix=suffix+1
  nodename[${suffix}]=${rest%%,*}
  lastName=${rest%%,*}
  rest=${rest#*,}
done

# build the commands to make the domain
myIndex=0
makeCommand="mkrpdomain ${tsa_domain_name} "
preprpCommand="preprpnode "
while true
do
  if [[ ${myIndex} = ${suffix} ]]
  then
    break
  fi
  let myIndex=myIndex+1
  makeCommand="${makeCommand}${nodename[${myIndex}]} "
  preprpCommand="${preprpCommand}${nodename[${myIndex}]} "
done

# determine IPv4 or IPv6
isIPv4AndIPv6

if [[ ("X${SCRIPT_OPTION}" = "X-createDomain") || ("X${SCRIPT_OPTION}" = "X-createCluster") ]]; then 
  startScript
  createDomain
  RC=$?
  if [[ $RC = 1 ]]
  then
    stopScript
    exit $domain_does_already_exist
  fi 
  if [[ $RC = 3 ]]
  then
    startDomain
    RC=$?
    if [[ $RC != 0 ]]
    then
      exit $RC
    fi 
    stopScript
    exit $domain_does_already_exist
  fi 
  if [[ $RC != 0 ]]
  then
    stopScript
    exit $RC
  fi 
  startDomain
  RC=$?
  if [[ $RC != 0 ]]
  then
    stopScript
    exit $RC
  fi 
  stopScript
  exit $ok
fi

if [[ ("X${SCRIPT_OPTION}" = "X-deleteDomain") || ("X${SCRIPT_OPTION}" = "X-deleteCluster") ]]; then 
  startScript
  deleteDomain
  RC=$?
  if [[ $RC != 0 ]]
  then
    stopScript
    exit $RC
  fi 
  stopScript
  exit $ok
fi

if [[ "X${SCRIPT_OPTION}" = "X-activatePolicy" ]]; then 
  startScript
  activatePolicy
  RC=$?
  if [[ $RC != 0 ]]
  then
    stopScript
    exit $RC
  fi 
  stopScript
  exit $ok
fi

if [[ "X${SCRIPT_OPTION}" = "X-checkPolicy" ]]; then 
  startScript
  checkPolicy
  RC=$?
  if [[ $RC != 0 ]]
  then
    stopScript
    exit $RC
  fi 
  stopScript
  exit $eezautomate_check_output
fi

if [[ "X${SCRIPT_OPTION}" = "X-deactivatePolicy" ]]; then 
  startScript
  deactivatePolicy
  RC=$?
  if [[ $RC != 0 ]]
  then
    stopScript
    exit $RC
  fi 
  stopScript
  exit $ok
fi

if [[ "X${SCRIPT_OPTION}" = "X-createAll" ]]; then 
  startScript
  createDomain
  RC=$?
  if [[ ($RC != 0) && ($RC != 1) && ($RC != 3) ]]
  then
    exit $RC
  fi 
  if [[ $RC != 1 ]]
  then
    startDomain
    RC=$?
    if [[ $RC != 0 ]]
    then
      exit $RC
    fi 
  fi
  sleep 15
  activatePolicy
  RC=$?
  if [[ $RC != 0 ]]
  then
    exit $RC
  fi 
  stopScript
  exit $ok
fi

if [[ "X${SCRIPT_OPTION}" = "X-deleteAll" ]]; then 
  startScript
  deactivatePolicy
  RC=$?
  if [[ $RC != 0 ]]
  then
    exit $RC
  fi 
  deleteDomain
  RC=$?
  if [[ $RC != 0 ]]
  then
    exit $RC
  fi 
  stopScript
  exit $ok
fi

#printHelp
# incorrect parameters used
logger -puser.debug "eezautomate: incorrect option used: ${SCRIPT_OPTION}" 
exit $bad_call